@@ -723,6 +723,14 @@ class BaseNetworkTest(test.BaseTestCase):
             router_id, subnet_id)
         return interface
 
+    @classmethod
+    def add_extra_routes_atomic(cls, *args, **kwargs):
+        return cls.client.add_extra_routes_atomic(*args, **kwargs)
+
+    @classmethod
+    def remove_extra_routes_atomic(cls, *args, **kwargs):
+        return cls.client.remove_extra_routes_atomic(*args, **kwargs)
+
     @classmethod
     def get_supported_qos_rule_types(cls):
         body = cls.client.list_qos_rule_types()
