@@ -16,9 +16,7 @@
 from oslo_log import log
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
-from tempest.lib import exceptions as lib_exc
 
-from neutron_tempest_plugin.common import ssh
 from neutron_tempest_plugin import config
 from neutron_tempest_plugin.scenario import base
 
@@ -70,19 +68,4 @@ class PortForwardingTestJSON(base.BaseTempestTestCase):
                 protocol="tcp")
             servers.append(server)
 
-        try:
-            for server in servers:
-                ssh_client = ssh.Client(
-                    self.fip['floating_ip_address'],
-                    CONF.validation.image_ssh_user,
-                    pkey=self.keypair['private_key'],
-                    port=server['port_forwarding']['external_port'])
-                self.assertIn(server['name'],
-                              ssh_client.exec_command('hostname'))
-        except lib_exc.SSHTimeout as ssh_e:
-            LOG.debug(ssh_e)
-            self._log_console_output(servers)
-            raise
-        except AssertionError:
-            self._log_console_output(servers)
-            raise
+        self.check_servers_hostnames(servers)
